# Generated by Django 2.2 on 2021-03-18 15:05

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('loducode_utils', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='city',
            name='created_by',
            field=models.ForeignKey(blank=True, help_text='user who created the object', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='city_created_by', to=settings.AUTH_USER_MODEL, verbose_name='creation user'),
        ),
        migrations.AddField(
            model_name='city',
            name='modified_by',
            field=models.ForeignKey(blank=True, help_text='user who performed the update', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='city_modified_by', to=settings.AUTH_USER_MODEL, verbose_name='update user'),
        ),
    ]
